#
# spec file for package metamath
#
# Copyright (c) 2019 SUSE LLC
# Copyright (c) 2016-2019 by Aaron Puchert
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Do not build LaTeX docs on SLES.
%if 0%{?is_opensuse}
%bcond_without  latex_doc
%else
%bcond_with     latex_doc
%endif

%define book_version 20190602

# Global definitions
Name:           metamath
Version:        0.180
Release:        lp152.1.29
Summary:        Formal proof verifier and proof assistant
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            http://us.metamath.org/
# Source links aren't stable. (They always points to the latest version.)
# http://us.metamath.org/downloads/metamath.tar.bz2
Source0:        %{name}.tar.bz2
# http://us.metamath.org/latex/metamath.tex
Source1:        %{name}.tex
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
%if %{with latex_doc}
BuildRequires:  texlive-amsfonts
BuildRequires:  texlive-anysize
BuildRequires:  texlive-bibtex-bin
BuildRequires:  texlive-breqn
BuildRequires:  texlive-hyperref
BuildRequires:  texlive-latex-bin
BuildRequires:  texlive-makecell
BuildRequires:  texlive-makeindex-bin
BuildRequires:  texlive-microtype
BuildRequires:  texlive-needspace
BuildRequires:  texlive-tabu
Recommends:     %{name}-book = %{book_version}-%{release}
%endif
Recommends:     %{name}-data = %{version}-%{release}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The Metamath language is a language to write theorems and formal proofs for
them. The Metamath program can parse files in the Metamath language and verify
the proofs. You can find examples of theories developed in Metamath on the
website.

%package book
Summary:        The Metamath book
License:        CC0-1.0
Group:          Productivity/Scientific/Math
Version:        %{book_version}
Release:        lp152.1.29
Requires:       %{name} = %{VERSION}-%{release}
BuildArch:      noarch

%description book
The Metamath book, written by Norman Megill with extensive revisions by
David A. Wheeler, provides an in-depth understanding of the Metamath language
and program. The first part of the book also includes an easy-to-read informal
discussion of abstract mathematics and computers, with references to other
proof verifiers and automated theorem provers.

%package data
Summary:        Data base files for %{name}
License:        CC0-1.0 AND GPL-2.0-or-later
Group:          Productivity/Scientific/Math
Requires:       %{name} = %{VERSION}-%{release}
BuildArch:      noarch

%description data
This package contains Metamath data base files for several formal theories.
* set.mm – Logic and set theory database (see Ch. 3 of the Metamath book).
* nf.mm – Logic and set theory database for Quine's New Foundations set theory.
* hol.mm – Higher order logic (simple type theory) database.
* iset.mm – Intuitionistic logic database.
* ql.mm – Quantum logic database.
* demo0.mm – Demo of simple formal system (see Ch. 2 of the Metamath book).
* miu.mm – Hofstadter's MIU-system (see Appendix D of the Metamath book).
* big-unifier.mm – A unification stress test (see comments in the file).
* peano.mm – A presentation of Peano arithmetic by Robert Solovay.

%prep
%setup -q -n %{name}
rm metamath.exe

%build
autoreconf -fi
%configure
make %{?_smp_mflags}

# Build documentation as outlined in the LaTeX file.
%if %{with latex_doc}
touch metamath.ind
touch special-settings.sty
pdflatex %{SOURCE1}
pdflatex %{SOURCE1}
bibtex metamath
makeindex metamath.ind
pdflatex %{SOURCE1}
pdflatex %{SOURCE1}
%endif

%install
%make_install
%if %{with latex_doc}
install -Dm0644 metamath.pdf %{buildroot}%{_datadir}/%{name}/%{name}.pdf
%endif

%files
%license LICENSE.TXT
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}

%if %{with latex_doc}
%files book
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/%{name}.pdf
%endif

%files data
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*.mm

%changelog
* Fri Dec 20 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 0.180.
  * MINIMIZE_WITH axiom trace now starts from current NEW_PROOF
    instead of SAVEd proof.
  * Make sure traceback flags are cleared after MINIMIZE_WITH.
  * Add url pointer to HELP WRITE SOURCE /SPLIT.
  * Clarify HELP WRITE SOURCE /REWRAP.
  * Add bug check info for user.
  * Use '|->' (not 'e.') as syntax hint for maps-to.
  * Remove extraneous </TD>.
  * Fix "line 0" in error msg when label clashes with math symbol.
  * Improve TOOLS> HELP INSERT, DELETE.
  * Change bug 1511 to error message.
  * Trigger Most Recent link on mmtheorems.html when there is a
    mathbox statement (currently set.mm and iset.mm).
  * Improve help for TOOLS> DELETE and SUBSTITUTE.
  * Change "htmlHome" in warnings to "htmlhome".
* Wed Sep 25 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 0.178.
- Update book to version 20190602.
- Remove Windows executable from sources before building.
* Wed May  1 2019 aaronpuchert@alice-dsl.net
- Update to version 0.177.
- Update book to version 20190407.
- Use man page from upstream now.
* Thu Apr  4 2019 aaronpuchert@alice-dsl.net
- Change SPDX identifier to GPL-2.0-or-later, as README.TXT states.
* Tue Mar 19 2019 aaronpuchert@alice-dsl.net
- Fix dependency versions - since the book has a different version,
  we need to be careful which version we refer to.
* Sat Mar 16 2019 aaronpuchert@alice-dsl.net
- Fix version number.
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Remove %%if..%%endif guards that do not change the build result.
- Itemize the list in the description.
* Sat Mar 16 2019 aaronpuchert@alice-dsl.net
- Update to version 0.175.
- Update Metamath book to version 20190307.
- Use date as version number for Metamath book, because it isn't
  versioned alongside the program.
- Move source links into comments, as they aren't stable. They
  always point to the latest version, which isn't compatible with
  download_files service runs.
* Thu Mar  7 2019 aaronpuchert@alice-dsl.net
- Update to version 0.174.
- Package Metamath book separately.
* Tue Jan  8 2019 aaronpuchert@alice-dsl.net
- Update to version 0.171.
* Mon Aug  6 2018 aaronpuchert@alice-dsl.net
- Update to version 0.163.
- Recommend data package, make it noarch.
* Sun Feb  4 2018 aaronpuchert@alice-dsl.net
- Add a brief manual page.
- Do not build LaTeX docs on SLES, because TeXlive doesn't seem up
  to the task there.
* Sun Feb  4 2018 aaronpuchert@alice-dsl.net
- Update to version 0.161.
- Also build documentation.
- Package data base files separately.
* Tue Oct 24 2017 aaronpuchert@alice-dsl.net
- Update version to 0.155.
* Wed Jul 19 2017 aaronpuchert@alice-dsl.net
- Really update version to 0.146.
* Wed Jul 19 2017 aaronpuchert@alice-dsl.net
- Update version to 0.146.
* Sat Apr 15 2017 aaronpuchert@alice-dsl.net
- Update version to 0.139.
* Mon Oct 31 2016 aaronpuchert@alice-dsl.net
- Initial release of the package base on version 0.130.
